@@ -127,57 +127,17 @@ Ext.m3.EditWindow = Ext.extend(Ext.m3.Window, {
 		return Ext.getCmp(this.formId).getForm();
 	}
 	/**
-	 * Проверяет форму на наличие некорректных полей, отдает список label'ов этих полей с указанием места нахождения
+	 * Проверяет форму на наличие некорректных полей, отдает список label'ов этих полей
 	 */
     ,getInvalidNames: function(submittedForm){
-        var invalidNames = [],
-            isContinueSearch,
-            currentElement,
-            parentElement,
-            parentComponent,
-            panelTitles,
-            invalidName;
-
-        submittedForm.items.each(function(f){
-            if(!f.validate()){
-                isContinueSearch = true;
-                currentElement = f.el;
-                panelTitles = [];
-
-                while(isContinueSearch) {
-                    parentElement = currentElement.parent();
-
-                    if (parentElement) {
-                        parentComponent = Ext.getCmp(parentElement.id);
-
-                        if (parentComponent) {
-                            if (parentComponent.getXType() == 'panel') {
-                                if (parentComponent.title) {
-                                    panelTitles.push('"' + parentComponent.title + '"');
-                                }
-                            } else if (parentComponent.getXType() == 'm3-editwindow') {
-                                isContinueSearch = false;
-                            }
-                        }
-
-                        currentElement = parentElement;
-                    } else {
-                        isContinueSearch = false;
-                    }
-                }
-
-                invalidName = '<br>- ' + f.fieldLabel;
-
-                if (panelTitles.length) {
-                    invalidName = invalidName + ' (на панели ' + panelTitles.join(' - ') + ')';
-                }
-
-                invalidNames.push(invalidName)
+                var invalidNames = [];
+                submittedForm.items.each(function(f){
+                   if(!f.validate()){
+                       invalidNames.push('<br>- ' + f.fieldLabel)
+                   }
+                });
+                return invalidNames
             }
-        });
-
-        return invalidNames;
-    }
     /**
 	 * Сообщить пользователю об имеющихся некорректно заполненных полях.
 	 * Будет использоваться для переопределения способа уведомления в потомках.
