@@ -332,12 +332,6 @@ Ext.extend(Ext.ux.grid.MultiGrouping, Ext.util.Observable, {
 	            });	
             }
             this.expandedItems = [];
-
-            this.grid.on('resize', function(grid, width, height, e){
-                // после изменения порядка группировки при изменении размеров
-                // окошка происходил наезд кнопок группировки друг на друга
-                grid.groupPlugin.resetLayout(grid.grouper.tbar);
-            });
         }
 	},
 	/**
@@ -421,10 +415,7 @@ Ext.extend(Ext.ux.grid.MultiGrouping, Ext.util.Observable, {
         // При явном вызове destroy event'ы не отсылаются. Удалим dragSource вручную.
         button.dd.destroy();
         button.destroy();
-        this.doGroup(this.getGroupColumns());
-        // надо подождать прогрузку, прежде чем обрабатывать атрибут left
-        var el = this;
-        setTimeout(function () {el.resetLayout(el.tbar)}, 500);
+        this.doGroup(this.getGroupColumns())
     },
     /**
      * Событие отрисовки панели группировки
@@ -542,7 +533,6 @@ Ext.extend(Ext.ux.grid.MultiGrouping, Ext.util.Observable, {
 				}
 	        }
 		}
-		this.resetLayout(this.tbar);
 	},
 	/**
 	 * Перед загрузкой выставим параметры загрузки
@@ -733,20 +723,6 @@ Ext.extend(Ext.ux.grid.MultiGrouping, Ext.util.Observable, {
             this.grid.getSelectionModel().selectRow(this.grid.store.totalLength-1);
     		e.stopEvent();
     		}
-    },
-    /**
-	 * после различных событий происходил наезд кнопок группировки
-     * друг на друга, так как не очищался css-атрибут left
-	 * @param {Ext.Toolbar} tbar Параметры события нажатия клавиши
-	 */
-    resetLayout: function(tbar) {
-        if (tbar) {
-            var items = tbar.items.items;
-            for (var i = 0; i < items.length; i++)
-                if (items[i].el)
-                    items[i].el.setStyle('left', 'auto');
-            tbar.layout.container.doLayout();
-        }
     }
 });
 
@@ -1113,19 +1089,11 @@ Ext.m3.MultiGroupingGridPanel = Ext.extend(Ext.ux.grid.livegrid.GridPanel, {
 	,onEditRecord: function (){
 		assert(this.actionEditUrl, 'actionEditUrl is not define');
 		assert(this.rowIdName, 'rowIdName is not define');
-
+		
 	    if (this.getSelectionModel().hasSelection()) {
-			/**
-            * на редактирование передается одна запись, которая была
-            * изначально загружена в грид быстрого просмотра
-             */
 			var baseConf = this.getSelectionContext(this.localEdit);
-            var sm = this.getSelectionModel();
-            var idField = this.getStore().idProperty;
-            var record = sm.getSelected();
-				baseConf[this.rowIdName] = record.json[idField];
 			var mask = new Ext.LoadMask(this.body);
-            var disableState = this.getToolbarsState();
+                        var disableState = this.getToolbarsState();
 			var req = {
 				url: this.actionEditUrl,
 				params: baseConf,
@@ -1456,7 +1424,6 @@ Ext.m3.MultiGroupingGridPanel = Ext.extend(Ext.ux.grid.livegrid.GridPanel, {
     }
 });
 
-Ext.reg('multigroupinggridpanel', Ext.m3.MultiGroupingGridPanel);
 
 /*******************
  * Плагин для экпорта в xls - отправляет на сервер запрос с нужными параметрами
